---
title: <span class="badge object-type-enum"></span> SearchTableType
---
# <span class="badge object-type-enum"></span> SearchTableType

The type of the table that is used to display the search results

## Definition

```python
class SearchTableType(enum.StrEnum):
    """
    The type of the table that is used to display the search results
    """

    TRACES = "traces"
    SPANS = "spans"
```
